==> nextcloud-app-deck-1:1.16.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/be.js <==
OC.L10N.register(
    "deck",
    {
    "The file was uploaded" : "Файл быў запампаваны.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Памер запампаванага файла перавышае значэнне дырэктывы upload_max_filesize у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Памер запампаванага файла перавышае значэнне дырэктывы MAX_FILE_SIZE у HTML форме",
    "The file was only partially uploaded" : "Файл быў запампаваны толькі часткова",
    "No file was uploaded" : "Ніводзін файл не быў запампаваны",
    "Missing a temporary folder" : "Адсутнічае часовая папка",
    "Could not write file to disk" : "Не ўдалося запісаць файл на дыск",
    "A PHP extension stopped the file upload" : "Пашырэнне PHP спыніла запампоўванне файла",
    "No file uploaded or file size exceeds maximum of %s" : "Файл не запампаваны, або памер файла перавышае максімальны %s",
    "copy" : "копія",
    "Done" : "Гатова",
    "File" : "Файл",
    "Invalid date, date format must be YYYY-MM-DD" : "Памылковая дата, дата павінна быць у фармаце ГГГГ-ММ-ДД",
    "Cancel" : "Скасаваць",
    "Drop your files to upload" : "Перацягніце файлы для запампоўвання",
    "File already exists" : "Файл ужо існуе",
    "A file with the name {filename} already exists." : "Файл з назвай {filename} ужо існуе.",
    "Do you want to overwrite it?" : "Хочаце перазапісаць яго?",
    "Overwrite file" : "Перазапісаць файл",
    "Keep existing file" : "Пакінуць існуючы файл",
    "Active filters" : "Актыўныя фільтры",
    "Apply filter" : "Ужыць фільтр",
    "Open" : "Адкрыць",
    "Clear filter" : "Ачысціць фільтр",
    "Open details" : "Адкрыць падрабязнасці",
    "Details" : "Падрабязнасці",
    "Sharing" : "Абагульванне",
    "Tags" : "Тэгі",
    "Activity" : "Актыўнасць",
    "Undo" : "Адрабіць",
    "Transfer" : "Перадаць",
    "(Group)" : "(Група)",
    "Can edit" : "Можа рэдагаваць",
    "Can share" : "Можа абагульваць",
    "Owner" : "Уладальнік",
    "Delete" : "Выдаліць",
    "Edit" : "Рэдагаваць",
    "Members" : "Удзельнікі",
    "File to share" : "Файл для абагульвання",
    "Invalid path selected" : "Выбраны памылковы шлях",
    "Share from Files" : "Абагуліць з Файлаў",
    "Show in Files" : "Паказаць у Файлах",
    "Download" : "Спампаваць",
    "Modified" : "Зменены",
    "Comments" : "Каментарыі",
    "Save" : "Захаваць",
    "Created:" : "Створана:",
    "Cancel reply" : "Скасаваць адказ",
    "Reply" : "Адказаць",
    "Update" : "Абнавіць",
    "Description" : "Апісанне",
    "Formatting help" : "Даведка па фармаціраванні",
    "Later today – {timeLocale}" : "Пазней сёння – {timeLocale}",
    "Set due date for later today" : "Задаць дату выканання на пазней сёння",
    "Tomorrow – {timeLocale}" : "Заўтра – {timeLocale}",
    "This weekend – {timeLocale}" : "У гэты ўік-энд – {timeLocale}",
    "Set due date for this weekend" : "Задаць дату выканання на гэты ўік-энд",
    "Next week – {timeLocale}" : "На наступным тыдні – {timeLocale}",
    "Set due date for next week" : "Задаць дату выканання на наступны тыдзень",
    "Create a new tag:" : "Стварыць новы тэг:",
    "(group)" : "(група)",
    "Todo items" : "Элементы спісу задач",
    "Open link" : "Адкрыць спасылку",
    "Edit title" : "Рэдагаваць загаловак",
    "seconds ago" : "с таму",
    "Keyboard shortcuts" : "Спалучэнні клавіш",
    "Keyboard shortcut" : "Спалучэнне клавіш",
    "Action" : "Дзеянне",
    "Shift" : "Shift",
    "Ctrl" : "Ctrl",
    "Search" : "Пошук",
    "Enter" : "Enter",
    "Shared with you" : "Абагулена з вамі",
    "Cancel edit" : "Скасаваць рэдагаванне",
    "An error occurred" : "Узнікла памылка",
    "No notifications" : "Няма апавяшчэнняў",
    "Export as CSV" : "Экспарт у CSV",
    "Export" : "Экспарт",
    "No results found" : "Вынікаў не знойдзена",
    "{stack} in {board}" : "{stack} у {board}",
    "Close" : "Закрыць",
    "Message from {author} in {conversationName}" : "Паведамленне ад {author} у {conversationName}",
    "Failed to upload {name}" : "Не ўдалося запампаваць {name}",
    "Share" : "Абагуліць",
    "Personal" : "Асабістыя",
    "Example Task 3" : "Прыклад задання 3",
    "Example Task 2" : "Прыклад задання 2",
    "Example Task 1" : "Прыклад задання 1",
    "Today" : "Сёння",
    "Tomorrow" : "Заўтра"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-app-deck-1:1.17.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/be.js <==
OC.L10N.register(
    "deck",
    {
    "The file was uploaded" : "Файл быў запампаваны.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Памер запампаванага файла перавышае значэнне дырэктывы upload_max_filesize у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Памер запампаванага файла перавышае значэнне дырэктывы MAX_FILE_SIZE у HTML форме",
    "The file was only partially uploaded" : "Файл быў запампаваны толькі часткова",
    "No file was uploaded" : "Ніводзін файл не быў запампаваны",
    "Missing a temporary folder" : "Адсутнічае часовая папка",
    "Could not write file to disk" : "Не ўдалося запісаць файл на дыск",
    "A PHP extension stopped the file upload" : "Пашырэнне PHP спыніла запампоўванне файла",
    "No file uploaded or file size exceeds maximum of %s" : "Файл не запампаваны, або памер файла перавышае максімальны %s",
    "copy" : "копія",
    "Done" : "Гатова",
    "Attachments" : "Далучэнні",
    "File" : "Файл",
    "Invalid date, date format must be YYYY-MM-DD" : "Памылковая дата, дата павінна быць у фармаце ГГГГ-ММ-ДД",
    "Cancel" : "Скасаваць",
    "Drop your files to upload" : "Перацягніце файлы для запампоўвання",
    "File already exists" : "Файл ужо існуе",
    "A file with the name {filename} already exists." : "Файл з назвай {filename} ужо існуе.",
    "Do you want to overwrite it?" : "Хочаце перазапісаць яго?",
    "Overwrite file" : "Перазапісаць файл",
    "Keep existing file" : "Пакінуць існуючы файл",
    "Add list" : "Дадаць спіс",
    "Active filters" : "Актыўныя фільтры",
    "Apply filter" : "Прымяніць фільтр",
    "Open" : "Адкрыць",
    "Clear filter" : "Ачысціць фільтр",
    "Open details" : "Адкрыць падрабязнасці",
    "Details" : "Падрабязнасці",
    "General" : "Агульныя",
    "Appearance" : "Знешні выгляд",
    "Admin settings" : "Налады адміністратара",
    "Search" : "Пошук",
    "Show those shortcuts" : "Паказаць гэтыя спалучэнні клавіш",
    "Sharing" : "Абагульванне",
    "Tags" : "Тэгі",
    "Activity" : "Актыўнасць",
    "Undo" : "Адрабіць",
    "Transfer" : "Перадаць",
    "(Group)" : "(Група)",
    "Can edit" : "Можа рэдагаваць",
    "Can share" : "Можа абагульваць",
    "Owner" : "Уладальнік",
    "Delete" : "Выдаліць",
    "Delete list" : "Выдаліць спіс",
    "Edit" : "Рэдагаваць",
    "Members" : "Удзельнікі",
    "File to share" : "Файл для абагульвання",
    "Invalid path selected" : "Выбраны памылковы шлях",
    "Share from Files" : "Абагуліць з Файлаў",
    "Show in Files" : "Паказаць у Файлах",
    "Download" : "Спампаваць",
    "Modified" : "Зменены",
    "Comments" : "Каментарыі",
    "Created:" : "Створана:",
    "Cancel reply" : "Скасаваць адказ",
    "Reply" : "Адказаць",
    "Update" : "Абнавіць",
    "Description" : "Апісанне",
    "Formatting help" : "Даведка па фармаціраванні",
    "Later today – {timeLocale}" : "Пазней сёння – {timeLocale}",
    "Set due date for later today" : "Задаць дату выканання на пазней сёння",
    "Tomorrow – {timeLocale}" : "Заўтра – {timeLocale}",
    "This weekend – {timeLocale}" : "У гэты ўік-энд – {timeLocale}",
    "Set due date for this weekend" : "Задаць дату выканання на гэты ўік-энд",
    "Next week – {timeLocale}" : "На наступным тыдні – {timeLocale}",
    "Set due date for next week" : "Задаць дату выканання на наступны тыдзень",
    "Create a new tag:" : "Стварыць новы тэг:",
    "(group)" : "(група)",
    "Todo items" : "Элементы спісу задач",
    "Open link" : "Адкрыць спасылку",
    "Edit title" : "Рэдагаваць загаловак",
    "seconds ago" : "с таму",
    "Shared with you" : "Абагулена з вамі",
    "Cancel edit" : "Скасаваць рэдагаванне",
    "An error occurred" : "Узнікла памылка",
    "No notifications" : "Няма апавяшчэнняў",
    "Export as CSV" : "Экспарт у CSV",
    "Export" : "Экспарт",
    "No results found" : "Вынікаў не знойдзена",
    "{stack} in {board}" : "{stack} у {board}",
    "Close" : "Закрыць",
    "Message from {author} in {conversationName}" : "Паведамленне ад {author} у {conversationName}",
    "Failed to upload {name}" : "Не ўдалося запампаваць {name}",
    "Share" : "Абагуліць",
    "Personal" : "Асабістыя",
    "Example Task 3" : "Прыклад задання 3",
    "Example Task 2" : "Прыклад задання 2",
    "Example Task 1" : "Прыклад задання 1",
    "Save" : "Захаваць",
    "Keyboard shortcuts" : "Спалучэнні клавіш",
    "Keyboard shortcut" : "Спалучэнне клавіш",
    "Action" : "Дзеянне",
    "Shift" : "Shift",
    "Ctrl" : "Ctrl",
    "Enter" : "Enter",
    "Today" : "Сёння",
    "Tomorrow" : "Заўтра"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
